==> hyperkyc_flutter-0.7.0.tar.gz: CHANGELOG.md <==
## CHANGELOG

### 0.7.0 *[ 06 Feb 2023 ]*
- Upgrade native iOS HyperKYC to `0.7.0`
  - Use ios hypersnap sdk 4.6.0
  - Add `supportedUploadFileTypes` via document module properties
  - Add support for Dynamic form module Phase 2
  - Add support for additional documents through `documentsOverride`
  - Add support for document name and type override for document module
  - Add support for `documentsSupported` ids to be injectable
  - Improvements to SDK start up time by fetching SDK configs etc in parallel
  - Improvements to UI/UX
  - Improvements to UI Config
  - Update `showReview` to be false and `showInstruction` to be true by default
  - Update document picker to use item ordering from `documentsSupported` array
  - Fix for boolean conditional checks
- Upgrade native android HyperKyc to `0.7.0`
  - Use android hypersnap sdk 4.6.0
  - Add `supportedUploadFileTypes` via document module properties
  - Add support for Dynamic form module Phase 2
  - Add support for additional documents through `documentsOverride`
  - Add support for document name and type override for document module
  - Add support for documentsSupported ids to be injectable
  - Improvements to SDK start up time by fetching SDK configs etc in parallel
  - Improvements to UI/UX
  - Update `showReview` to be false and `showInstruction` to be true by default
  - Update document picker to use item ordering from `documentsSupported` array
  - Update read/write timeouts to 60 sec for API module
  - Update the rules evaluator to support - in rules value
  - Fix HyperKycConfig serialization issue - adds gson rules to consumer-rules.pro
  - Fix and replace unsupported datetime methods <API26
  
### 0.3.4 *[ 12 Jan 2023 ]*
- Upgrade native iOS HyperKYC to `0.3.10`
  - Fixes side text translations - front and back
  - Update font and font weight keys
  - Enable text config for device orientation
- Upgrade native android HyperKyc to `0.3.14`
  - Fixes side text translations - front and back
  - Fix fonts rendering logic to use font file extensions
  - Change font family and font weight keys to reflect PRD and websdk
  - Remove hard coded strings pointing to Mixpanel API

### 0.6.0 *[ 16 Dec 2022 ]*
- Upgrade native iOS HyperKYC to `0.6.0`
- Upgrade native android HyperKyc to `0.6.0`

### 0.3.3 *[ 13 Dec 2022 ]*
- Upgrade native iOS HyperKYC to `0.3.9`
- Upgrade native android HyperKyc to `0.3.13`

### 0.5.0 *[02 Dec 2022]*
- Upgrade native iOS HyperKYC to `0.5.0` - Includes `DocDetect`
- Upgrade native android HyperKyc to `0.5.0` - Includes `DocDetect`
- Update deployment target to 11 (for iOS)
- Update compileSDK version to 33 (for android)

** Please note that 0.4.0 version does not exist. We have taken this decision to maintain version number consistency between all the platforms that we support ** 

### 0.3.2 *[ 07 Nov 2022 ]*
- Upgrade native iOS HyperKYC to `0.3.8`
- Upgrade native android HyperKyc to `0.3.11`
- Pass sdk-version and sdk-type metadata to native SDKs (internal usage only)
- Obtain rawDataJsonString from native SDKs (internal usage only)

### 0.3.1 *[ 30 Sep 2022 ]*

- Upgrade native iOS HyperKYC to `0.3.4`
- Upgrade native android HyperKyc to `0.3.6`
- Update compileSDK version to 31 (for android)

### 0.3.0 *[ 12 Aug 2022 ]*

- Upgrade native iOS HyperKYC to `0.3.0`
- Upgrade native android HyperKyc to `0.3.1`
- **Breaking Change** - SDK Response restructure

### 0.2.0 *[ 16 Jun 2022 ]*

- Upgrade native iOS HyperKYC to `0.2.1`
- Upgrade native android HyperKyc to `0.0.5-alpha01`
- **Breaking Change** - Add support for workflowId and custom inputs

### 0.0.5 *[ 22 Apr 2022 ]*

- Upgrade native iOS HyperKYC to `0.1.0`
- Upgrade native android HyperKyc to `0.0.3-alpha01`
- UI/UX revamp

### 0.0.4 *[ 23 Mar 2022 ]*

- Upgrade native iOS HyperKYC to `0.0.7`
- Upgrade native android HyperKyc to `0.0.2-alpha04`
- Add extra doc quality checks members to DocQualityChecks class

### 0.0.3 *[ 11 Mar 2022 ]*

- Upgrade native iOS HyperKYC to `0.0.6`
- Upgrade native android HyperKyc to `0.0.2-alpha03`
- Upgrade Flutter bridge files to support configurable workflow
- Update README

### 0.0.2 *[ 02 Feb 2022 ]*

- Upgrade native iOS HyperKyc to `0.0.4`
- Fix minor bugs
- Update README
- Add documentation to all public properties

### 0.0.1 *[ 01 Feb 2022 ]*

- Release Aplha Version with native Android HyperKyc `0.0.1-alpha02` and native iOS HyperKyc `0.0.3`

==> hyperkyc_flutter-0.7.5.tar.gz: CHANGELOG.md <==
## CHANGELOG

### 0.7.5 *[ 24 Mar 2023 ]*
- Upgrade native iOS HyperKyc to `0.7.2`
  - Use HyperSnap SDK `4.6.3`
    - Fix font specific issues for UI config
- Upgrade native android HyperKYC to `0.7.4`
  - Use HyperSnap SDK `4.6.4`
    - Support fonts added in any sub-folder within the assets folders
    - Fix multiple UI config edge case bugs
  - Add support for `,` character within rules

### 0.7.4 *[ 07 Mar 2023 ]*
- Upgrade native iOS HyperKyc to `0.7.2`
  - Use HyperSnap SDK `4.6.2`
    - Fixes to UI config issues :
      - Text size getting overwritten
      - Animations overlapping in small screens 
      - Retake screen attributed string 
      - Absence of borderWidth for Primary buttons
      - Color of status text not changing
    - Fixes to Text config issues :
      - In-line Loader text config issues 
      - Sync with web sdk text configs
        - Change `faceCapture_autoCaptureWait` to `faceAutoCapture_stayStill`
        - Change `faceCapture_autoCaptureAction` to `faceAutoCapture_labelChange`
- Upgrade native android HyperKYC to `0.7.3`
  - Use HyperSnap SDK `4.6.3`
    - Fixes to UI config issues 
    - Sync with web sdk text configs 
      - Change `faceCapture_autoCaptureWait` to `faceAutoCapture_stayStill` 
      - Change `faceCapture_autoCaptureAction` to `faceAutoCapture_labelChange`

### 0.7.3 *[ 27 Feb 2023 ]*
- Upgrade native iOS HyperKyc to `0.7.1`
  - Use HyperSnap SDK `4.6.1`
    - Add fix for lottie animation not loading
    - UI/UX bug fixes
  - Fix request body issue in api module
- Upgrade native android HyperKYC to `0.7.2`
  - Use HyperSnap SDK `4.6.1`
    - Add text config support for doc upload button; use `docInstructions_uploadButton`
    - Add support for camera API switch in SDK
  - Fix `HVResponse.videoUri` not exposed via `videoPath` bug

### 0.7.2 *[ 13 Feb 2023 ]*
- Upgrade native android HyperKYC to `0.7.1`
  - Add error message to API call failure results
  - Add `transactionId` to sentry crashes
  - Fix `null` in headers bug which made calls fail for `API` module
  - Fix `HyperKycConfig.addMetadata` implementation

### 0.7.1 *[ 13 Feb 2023 ]*
- Please note that this version has been retracted

### 0.7.0 *[ 06 Feb 2023 ]*
- Upgrade native iOS HyperKYC to `0.7.0`
  - Use ios hypersnap sdk `4.6.0`
  - Add `supportedUploadFileTypes` via document module properties
  - Add support for Dynamic form module Phase 2
  - Add support for additional documents through `documentsOverride`
  - Add support for document name and type override for document module
  - Add support for `documentsSupported` ids to be injectable
  - Improvements to SDK start up time by fetching SDK configs etc in parallel
  - Improvements to UI/UX
  - Improvements to UI Config
  - Update `showReview` to be false and `showInstruction` to be true by default
  - Update document picker to use item ordering from `documentsSupported` array
  - Fix for boolean conditional checks
- Upgrade native android HyperKyc to `0.7.0`
  - Use android hypersnap sdk `4.6.0`
  - Add `supportedUploadFileTypes` via document module properties
  - Add support for Dynamic form module Phase 2
  - Add support for additional documents through `documentsOverride`
  - Add support for document name and type override for document module
  - Add support for documentsSupported ids to be injectable
  - Improvements to SDK start up time by fetching SDK configs etc in parallel
  - Improvements to UI/UX
  - Update `showReview` to be false and `showInstruction` to be true by default
  - Update document picker to use item ordering from `documentsSupported` array
  - Update read/write timeouts to 60 sec for API module
  - Update the rules evaluator to support - in rules value
  - Fix HyperKycConfig serialization issue - adds gson rules to consumer-rules.pro
  - Fix and replace unsupported datetime methods <API26
  
### 0.3.4 *[ 12 Jan 2023 ]*
- Upgrade native iOS HyperKYC to `0.3.10`
  - Fixes side text translations - front and back
  - Update font and font weight keys
  - Enable text config for device orientation
- Upgrade native android HyperKyc to `0.3.14`
  - Fixes side text translations - front and back
  - Fix fonts rendering logic to use font file extensions
  - Change font family and font weight keys to reflect PRD and websdk
  - Remove hard coded strings pointing to Mixpanel API

### 0.6.0 *[ 16 Dec 2022 ]*
- Upgrade native iOS HyperKYC to `0.6.0`
- Upgrade native android HyperKyc to `0.6.0`

### 0.3.3 *[ 13 Dec 2022 ]*
- Upgrade native iOS HyperKYC to `0.3.9`
- Upgrade native android HyperKyc to `0.3.13`

### 0.5.0 *[02 Dec 2022]*
- Upgrade native iOS HyperKYC to `0.5.0` - Includes `DocDetect`
- Upgrade native android HyperKyc to `0.5.0` - Includes `DocDetect`
- Update deployment target to 11 (for iOS)
- Update compileSDK version to 33 (for android)

---
** Please note that 0.4.0 version does not exist. We have taken this decision to maintain version number consistency between all the platforms that we support ** 
---

### 0.3.2 *[ 07 Nov 2022 ]*
- Upgrade native iOS HyperKYC to `0.3.8`
- Upgrade native android HyperKyc to `0.3.11`
- Pass sdk-version and sdk-type metadata to native SDKs (internal usage only)
- Obtain rawDataJsonString from native SDKs (internal usage only)

### 0.3.1 *[ 30 Sep 2022 ]*

- Upgrade native iOS HyperKYC to `0.3.4`
- Upgrade native android HyperKyc to `0.3.6`
- Update compileSDK version to 31 (for android)

### 0.3.0 *[ 12 Aug 2022 ]*

- Upgrade native iOS HyperKYC to `0.3.0`
- Upgrade native android HyperKyc to `0.3.1`
- **Breaking Change** - SDK Response restructure

### 0.2.0 *[ 16 Jun 2022 ]*

- Upgrade native iOS HyperKYC to `0.2.1`
- Upgrade native android HyperKyc to `0.0.5-alpha01`
- **Breaking Change** - Add support for workflowId and custom inputs

### 0.0.5 *[ 22 Apr 2022 ]*

- Upgrade native iOS HyperKYC to `0.1.0`
- Upgrade native android HyperKyc to `0.0.3-alpha01`
- UI/UX revamp

### 0.0.4 *[ 23 Mar 2022 ]*

- Upgrade native iOS HyperKYC to `0.0.7`
- Upgrade native android HyperKyc to `0.0.2-alpha04`
- Add extra doc quality checks members to DocQualityChecks class

### 0.0.3 *[ 11 Mar 2022 ]*

- Upgrade native iOS HyperKYC to `0.0.6`
- Upgrade native android HyperKyc to `0.0.2-alpha03`
- Upgrade Flutter bridge files to support configurable workflow
- Update README

### 0.0.2 *[ 02 Feb 2022 ]*

- Upgrade native iOS HyperKyc to `0.0.4`
- Fix minor bugs
- Update README
- Add documentation to all public properties

### 0.0.1 *[ 01 Feb 2022 ]*

- Release Aplha Version with native Android HyperKyc `0.0.1-alpha02` and native iOS HyperKyc `0.0.3`
